@@ -158,6 +158,9 @@ def toSymbol(t, scope, line):
             return val(t, "name")
         else:
             key = toSymbol(get(t, "expression"), scope, line)
+            # key is a variable
+            if not "string/" in key:
+                key = match(line, key, scope, "")
             name = f"{toSymbol(t.children[0],  scope, line)}.{key}"
             return name
 
@@ -522,14 +525,19 @@ def toPython(t, state, indent, scope):
 
         # first parse the variable if it is there.
         variable = None
-        if (var := get(t, "variable")) is not None:
+        if (var := get(t, "variable")) is not None or (var := get(t, "class_variable")) is not None:
             variable = toPython(var, state, "", scope)
-            if variable == "self":
+            if variable[:4] == "self":
                 symbol = scope.split(".")[0]
             else:
                 symbol = symbolType(line, toSymbol(get(t, "variable"), scope, line), scope)
             if f"{symbol}.{function}" not in user_functions:
                 raise StartError(f"In line {line}: Function <{function}> not defined in <{symbol}>!")
+
+            # Make sure to use getattr if you use a nested variable
+            if get(t, 'variable') and get(t.children[0], 'variable'):
+                variable = f"getattr({variable})"
+
             return f"{variable}.{function}({arguments})"
 
         if function not in user_functions and function not in built_in_functions:
